@@ -460,181 +460,3 @@ def gen_pdf_report(fn):
     ret = run(["mv", fn2, dn])
     ret = run(["rm", fn1])
 
-def create_uid():
-    ww,mm,dd,tt,yy = time.asctime().split(' ')
-    return f"{yy}{mm}{dd}-{tt}-{str(uuid.uuid4())[:8]}"
-
-
-def run_task(client, cmd, cwd, prerequire=[], shell=False, quiet=False):
-    """ run cmd, in cwd
-        cmd should be a list (*args), if shell is False
-        when wildcards are used, shell should be Ture, and cmd is just a string
-        prerequire is a list of futures that must be gathered before the cmd can run
-    """
-    if not quiet:
-        print(f"starting job {cmd} in {cwd}")
-    client.gather(prerequire)
-    return client.submit(subprocess.run, cmd,
-                         stdout=subprocess.PIPE,stderr=subprocess.STDOUT,
-                         shell=shell, check=True, cwd=cwd, key=create_uid())
-        
-#server_atsas_path = "/opt/apps/ATSAS/2.8.5-0/bin"
-server_atsas_path = "/usr/bin"
-
-def getNSD(msg):
-    # msg is the output from supcomb 
-    # NSD appears to be the smalles value in the final distance column in the output
-    # Read file .............................................. : t-00-1.pdb
-    # Number of atoms ........................................ : 236
-    # Fineness of the structure .............................. : 8.400
-    # Read file .............................................. : t-01-1.pdb
-    # Number of atoms ........................................ : 236
-    # Fineness of the structure .............................. : 8.400
-    #
-    #                                Initial       Final
-    #              Orientation      Distance    Distance
-    #             1     1     1       1.3553      1.1500
-    #             1     1    -1       1.2461      1.1552
-    #             1    -1     1       1.4394      1.1577
-    #             1    -1    -1       1.2884      1.1466
-    #            -1     1     1       1.8763      1.5808
-    #            -1     1    -1       1.9531      1.4054
-    #            -1    -1     1       1.8619      1.4467
-    #            -1    -1    -1       1.9294      1.4217
-    #
-    #                   Transformation matrix
-    #         0.5193     -0.7225      0.4565     -0.9402
-    #         0.0398     -0.5131     -0.8574     -6.5252
-    #         0.8537      0.4634     -0.2377     -0.5459
-    #         0.0000      0.0000      0.0000      1.0000
-    #
-    # Wrote file ............................................. : t-01-1r.pdb
-    lines = msg.split("\n")
-    nsd = -1
-    for i in range(len(lines)):
-        if lines[i].find("Distance")<0:
-            continue
-        vals = [float(lines[i+j+1].split(" ")[-1]) for j in range(8)]
-        nsd = np.min(vals)
-        break
-    if nsd<0:
-        raise Exception("could not find NSD")
-    return nsd
-    
-    
-def damaver(client, fns, cwd, prerequire, debug=False):
-    """
-    options: NOT YET IMPLEMENTED
-        --symmetry=<SYMMETRY>
-        --enantiomorphs=<YES|NO>
-        --nbeads=<N> (damaver only)
-
-    damaver(pdbs):
-        loop over pdbi, pdbj:
-            supcomb pdbi pdbj
-        assemble NSD table
-        discard files with nsd > Mean + 2*Standard deviation (damaver/damsel manual)
-        loop over remaining pdbs pdbi, except for the ref:
-            damsup pdb_ref pdbi
-        damaver aligned_pdbs
-        damfilt damaver.pdb
-        damstart damaver.pdb    
-    """
-
-    npdb = len(fns)
-    if npdb<2:
-        return
-    
-    futures = []
-    index = []
-    print("calculating NSDs as models become available ...")
-    #for i in range(npdb-1):
-    #    for j in range(i+1, npdb):
-    #        f = run_task(client,
-    #                     cmd=[f"{server_atsas_path}/bin/supcomb", fns[i], fns[j], "-o", f"supcomb{i}-{j}.pdb"], 
-    #                     cwd=cwd,
-    #                     prerequire = [prerequire[i], prerequire[j]], quiet=True)
-    #        futures.append(f)
-    #        index.append([i,j])
-    res_list = []
-    for future,result in as_completed(prerequire, with_results=True):
-        res_no = int(result.args[2][-2:]) # e.g. ['dammif', '--mode=FAST', '--prefix=t-03', '../t.out']
-        res_list.append(res_no)
-        print(f"model #{res_no:02d} completed ...")
-        n = len(res_list)
-        if n>2:
-            for i in range(n-1):
-                n1 = np.min([res_list[i], res_list[-1]])
-                n2 = np.max([res_list[i], res_list[-1]])
-                f = run_task(client,
-                             cmd=[os.path.join(server_atsas_path, "supcomb"), 
-                                  fns[n1], fns[n2], 
-                                  "-o", f"supcomb{n1}-{n2}.pdb"], 
-                             cwd=cwd, quiet=True)
-                futures.append(f)
-                index.append([n1,n2])
-    
-    nsds = np.zeros([npdb, npdb])
-    for i in range(len(futures)):
-        i1,i2 = index[i]
-        nsd = getNSD(futures[i].result().stdout.decode())
-        nsds[i1][i2] = nsd
-        nsds[i2][i1] = nsd
-        if debug:
-            print(f"NSD({i1:02d},{i2:02d}) = {nsd:.3f}")
-    # average NSD for each structure
-    for i in range(npdb):
-        nsds[i][i] = np.average([nsds[i,j] for j in range(npdb) if j!=i])
-    # damsel exclude structures with NSD-avg(NSD)>2*std
-    dd = nsds.diagonal()
-    if debug:
-        print("averaged NSDs:", dd)
-    selected = [i for i in range(npdb) if np.fabs(dd[i]-np.average(dd))<np.std(dd)*2]
-    print("structures selected: ", selected)
-
-    print("cleaning up ...")
-    fns_list = [[os.path.join(cwd, f"supcomb{selected[0]}-{i}.pdb"), 
-                 os.path.join(cwd, f"{fns[i][:-4]}r.pdb")] for i in selected[1:]]
-    futures = [client.submit(os.rename, *fns) for fns in fns_list]
-    client.gather(futures)
-    fn_list = client.submit(glob.glob, 
-                            os.path.join(cwd, "supcomb*-*.pdb")).result()
-    client.gather(client.submit(lambda x: [os.remove(x0) for x0 in x], fn_list))
-
-    pdb_list = [fns[selected[0]]] + [f"{fns[i][:-4]}r.pdb" for i in selected[1:]]
-    client.gather(run_task(client, cmd=[os.path.join(server_atsas_path, "damaver")] + pdb_list, cwd=cwd))
-    client.gather(run_task(client, cmd=[os.path.join(server_atsas_path, "damfilt"), "damaver.pdb"], cwd=cwd))
-    client.gather(run_task(client, cmd=[os.path.join(server_atsas_path, "damstart"), "damaver.pdb"], cwd=cwd))
-    
-    return selected
-    
-def model_data(client, fn, rep=10, subdir=None):
-    """ repeat a bunch of dammif runs
-        then run damaver on the results
-    """
-    
-    if rep>99:
-        rep = 99
-    dfn = os.path.basename(fn)            # data file name
-    sn = dfn[:-4]                         # sample name, strip off the .out extension from dfn
-    if subdir is None:
-        subdir = sn
-    cwd = f"{os.path.dirname(fn)}/{subdir}"   # data file path
-    if not os.path.exists(cwd):
-        future = run_task(client, cmd=["mkdir", cwd], cwd="./")
-        client.gather(future)
-    
-    dammif_cmds = [[os.path.join(server_atsas_path, "dammif"), "--mode=FAST", 
-                    f"--prefix={sn}-{i:02d}", f"../{dfn}"] for i in range(rep)]
-    futures = [run_task(client, cmd=cmd, cwd=cwd) for cmd in dammif_cmds]
-    
-    print("starting damaver ...")
-    damaver(client, [f"{sn}-{i:02d}-1.pdb" for i in range(rep)], cwd, futures)
-    
-    print("cleaning up ...") 
-    # rename file to avoid future conflict
-    fns = ["damaver.pdb", "damfilt.pdb", "damstart.pdb"]
-    for fn in fns:
-        client.gather(client.submit(os.rename, f"{cwd}/{fn}", f"{cwd}/{sn}-{fn}"))
-
-    print("done")
\ No newline at end of file
