@@ -9,11 +9,41 @@ import pylab as plt
 import glob,uuid,re,pathlib,os
 import ipywidgets
 from IPython.display import display,clear_output
+import webbrowser,qrcode,base64
 
 def makeQRxls(fn, n=10):
     qdict = {"UIDs" : [uuid.uuid4() for _ in  range(n)] }
     df = pd.DataFrame.from_dict(qdict)
     df.to_excel(fn, index=False)
+
+def make_plate_QR_code(proposal_id, SAF_id, plate_id, path=""):
+    """ depends on blabel
+        generate a pdf file, with plate outline
+    """
+    code = [str(proposal_id), str(SAF_id), str(plate_id)]
+    if len(code[0])!=6 or len(code[1])!=6:
+        raise Exception("Proposal and SAF IDs should each have 6 digits.")
+    if len(code[2])!=2:
+        raise Exception("Plate IDs should have 2 digits.")
+    str_in = '-'.join(code)
+    fn = f"plate_{str_in}.html"
+    if path!="":
+        fn = os.path.join(path, fn)
+
+    lixtools_dir = os.path.dirname(os.path.realpath(__file__))
+    template_fn = os.path.join(lixtools_dir, "plate_label_template.html")
+    with open(template_fn, "r") as fh:
+        txt = fh.read()
+    img = qrcode.make(str_in)
+    img_byte_arr = BytesIO()
+    img.save(img_byte_arr, format='PNG')
+    bb = img_byte_arr.getvalue()
+    txt = txt.replace("**CODE**", str_in)
+    txt = txt.replace("**IMAGE**", base64.b64encode(bb).decode())
+    with open(fn, "w") as fh:
+        fh.write(txt)
+    webbrowser.open(f'file:///{os.path.realpath(fn)}')
+    
     
 def make_barcode(proposal_id, SAF_id, plate_id, path="", max_width=2.5, max_height=0.4, 
                  module_height=3.5, module_width=0.25, text_distance=0.5, font_size=10):
@@ -126,7 +156,8 @@ def validate_sample_list(xls_fn,
         msg.append(f"Consider consolidating the rows, more than two rows are half full.")
 
     if generate_barcode:
-        bcode,bcode_img = make_barcode(proposal_id, SAF_id, plate_id, dirname(xls_fn))
+        bcode,bcode_img = make_plate_QR_code(proposal_id, SAF_id, plate_id, dirname(xls_fn))
+        #bcode,bcode_img = make_barcode(proposal_id, SAF_id, plate_id, dirname(xls_fn))
         msg.append(f"writing barcode to {bcode}.pdf ...")
         #plt.imshow(bcode_img)
         display(bcode_img)
